==> risk-center-api-0.2.0-20180627.023308-15-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/req/ReqRiskReviewQuery.java <==
package cn.com.duiba.tuia.risk.center.api.dto.req;/**
 * Created by chengdeman .
 * 18/3/1 .
 */

import java.io.Serializable;

/**
 * 风控审核查询
 *
 * @author chengdeman
 * @create 2018-03-01 上午10:01
 **/
public class ReqRiskReviewQuery extends  ReqPageQuery implements Serializable{

    private static final long serialVersionUID = -2590705433551438548L;

    /**
     * 广告位ID
     */
    private Long slotId;

    /**
     * APPid
     */
    private Long appId;

    /**
     * 审核人
     */
    private String riskReviewer;


	/**
	 * 实时，离线，全部 = 1，2，3
	 */
	private Integer type;

    /**
     * 作弊等级
     */
    private String cheatGrade;

    // 最终状态
    private Integer reviewResult;

    /**
     * 初步状态
     */
    private Integer preResult;


    public Integer getPreResult() {
        return preResult;
    }

    public void setPreResult(Integer preResult) {
        this.preResult = preResult;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getRiskReviewer() {
        return riskReviewer;
    }

    public void setRiskReviewer(String riskReviewer) {
        this.riskReviewer = riskReviewer;
    }

	public Integer getType() {
		return type;
	}

	public void setType(Integer type) {
		this.type = type;
	}

	public String getCheatGrade() {
        return cheatGrade;
    }

    public void setCheatGrade(String cheatGrade) {
        this.cheatGrade = cheatGrade;
    }

    public Integer getReviewResult() {
        return reviewResult;
    }

    public void setReviewResult(Integer reviewResult) {
        this.reviewResult = reviewResult;
    }
}

==> risk-center-api-0.4.4-20180907.061608-2-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/req/ReqRiskReviewQuery.java <==
package cn.com.duiba.tuia.risk.center.api.dto.req;/**
 * Created by chengdeman .
 * 18/3/1 .
 */

import java.io.Serializable;

/**
 * 风控审核查询
 *
 * @author chengdeman
 * @create 2018-03-01 上午10:01
 **/
public class ReqRiskReviewQuery extends  ReqPageQuery implements Serializable{

    private static final long serialVersionUID = -2590705433551438548L;

    /**
     * 广告位ID
     */
    private Long slotId;

    /**
     * APPid
     */
    private Long appId;

    /**
     * 审核人
     */
    private String riskReviewer;


	/**
	 * 实时，离线，全部 = 1，2，3
	 */
	private Integer type;

    /**
     * 作弊等级
     */
    private String cheatGrade;

    // 最终状态
    private Integer reviewResult;

    /**
     * 初步状态
     */
    private Integer preResult;

    /**
     * 媒体处理意见：1 同意 0 拒绝  -1 全部
     */
    private Integer mediaDealOpinion;

    /**
     * 处理时间：1 上午11:30 2 下午 14:00  -1 全部
     */
    private Integer dealDate;


    public Integer getPreResult() {
        return preResult;
    }

    public void setPreResult(Integer preResult) {
        this.preResult = preResult;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getRiskReviewer() {
        return riskReviewer;
    }

    public void setRiskReviewer(String riskReviewer) {
        this.riskReviewer = riskReviewer;
    }

	public Integer getType() {
		return type;
	}

	public void setType(Integer type) {
		this.type = type;
	}

	public String getCheatGrade() {
        return cheatGrade;
    }

    public void setCheatGrade(String cheatGrade) {
        this.cheatGrade = cheatGrade;
    }

    public Integer getReviewResult() {
        return reviewResult;
    }

    public void setReviewResult(Integer reviewResult) {
        this.reviewResult = reviewResult;
    }

    public Integer getMediaDealOpinion() {
        return mediaDealOpinion;
    }

    public void setMediaDealOpinion(Integer mediaDealOpinion) {
        this.mediaDealOpinion = mediaDealOpinion;
    }

    public Integer getDealDate() {
        return dealDate;
    }

    public void setDealDate(Integer dealDate) {
        this.dealDate = dealDate;
    }
}
